Module debug_print

Module debug_print 

Functions

debug_hir
format_errors
format_hir_function_into
Format an HIR function into a reactive PrintFormatter. This bridges the two debug printers so inner functions in FunctionExpression/ObjectMethod can be printed within the reactive function output.