CompilerErrorInfo

Struct CompilerErrorInfo 

pub struct CompilerErrorInfo {
    pub reason: String,
    pub description: Option<String>,
    pub details: Vec<CompilerErrorDetailInfo>,
    pub raw_message: Option<String>,
    pub formatted_message: Option<String>,
}
Structured error information for the JS shim.

Fields

reason: Stringdescription: Option<String>details: Vec<CompilerErrorDetailInfo>raw_message: Option<String>

When set, the JS shim should throw an Error with this exact message instead of formatting through formatCompilerError(). This is used for simulated unknown exceptions (throwUnknownException__testonly) which in the TS compiler are plain Error objects, not CompilerErrors.

formatted_message: Option<String>

Pre-formatted error message produced by Rust, matching the JS formatCompilerError() output. When present, the JS shim uses this directly instead of calling formatCompilerError() on the JS side.