Module gating

Module gating 

Structs

GatingRewrite
Represents a compiled function that needs gating. In the Rust version, we work with indices into the program body rather than Babel paths.

Enums

CompiledFunctionNode
A compiled function node, can be any function type.

Functions

apply_gating_rewrites
Apply gating rewrites to the program. This modifies program.body by replacing/inserting statements.