pub fn get_react_compiler_runtime_module(target: &CompilerTarget) -> StringExpand description
Get the runtime module name based on the compiler target.
pub fn get_react_compiler_runtime_module(target: &CompilerTarget) -> StringGet the runtime module name based on the compiler target.