Module suppression

Module suppression 

Structs

SuppressionRange
Captures the start and end range of a pair of eslint-disable … eslint-enable comments. In the case of a CommentLine or a relevant Flow suppression, both the disable and enable point to the same comment.

Enums

SuppressionSource

Functions

filter_suppressions_that_affect_function
Check if suppression ranges overlap with a function’s source range. A suppression affects a function if:
find_program_suppressions
Parse eslint-disable/enable and Flow suppression comments from program comments. Equivalent to findProgramSuppressions in Suppression.ts
suppressions_to_compiler_error
Convert suppression ranges to a CompilerError.