Module validate_source_locations

Module validate_source_locations 

Validates that important source locations from the original code are preserved in the generated AST. This ensures that Istanbul coverage instrumentation can properly map back to the original source code.

This validation is test-only, enabled via @validateSourceLocations pragma.

Analogous to TS ValidateSourceLocations.ts.

Functions

validate_source_locations
Validate that important source locations are preserved in the generated AST.