pub fn validate_source_locations(
func: &FunctionNode<'_>,
codegen: &CodegenFunction,
env: &mut Environment,
)Expand description
Validate that important source locations are preserved in the generated AST.
pub fn validate_source_locations(
func: &FunctionNode<'_>,
codegen: &CodegenFunction,
env: &mut Environment,
)Validate that important source locations are preserved in the generated AST.