Functions
- debug_
hir - format_
errors - format_
hir_ function_ into - Format an HIR function into a reactive PrintFormatter. This bridges the two debug printers so inner functions in FunctionExpression/ObjectMethod can be printed within the reactive function output.