format_hir_function_into

Function format_hir_function_into 

pub fn format_hir_function_into(
    reactive_fmt: &mut PrintFormatter<'_>,
    func: &HirFunction,
)
Format an HIR function into a reactive PrintFormatter. This bridges the two debug printers so inner functions in FunctionExpression/ObjectMethod can be printed within the reactive function output.