Re-exports
pub use compile_result::*;pub use plugin_options::*;pub use program::*;
Modules
- compile_
result - gating
- imports
- pipeline
- Compilation pipeline for a single function.
- plugin_
options - program
- Main entrypoint for the React Compiler.
- suppression
- validate_
source_ locations - Validates that important source locations from the original code are preserved in the generated AST. This ensures that Istanbul coverage instrumentation can properly map back to the original source code.