Structs
- Suppression
Range - Captures the start and end range of a pair of eslint-disable … eslint-enable comments. In the case of a CommentLine or a relevant Flow suppression, both the disable and enable point to the same comment.
Enums
Functions
- filter_
suppressions_ that_ affect_ function - Check if suppression ranges overlap with a function’s source range. A suppression affects a function if:
- find_
program_ suppressions - Parse eslint-disable/enable and Flow suppression comments from program comments. Equivalent to findProgramSuppressions in Suppression.ts
- suppressions_
to_ compiler_ error - Convert suppression ranges to a CompilerError.